import 'package:get/get.dart';
import 'package:get_storage/get_storage.dart';
import 'package:hordev2/app/data/models/base_model.dart';
import 'package:hordev2/app/data/models/company_model.dart';
import 'package:hordev2/app/data/models/sensor_model.dart';
import 'package:hordev2/app/data/providers/dummy_providers.dart';

BaseProvider getProvider(String name) {
  Map<String, dynamic> models = {
    'sensor': {"uri": "sensor", "model": Sensor, "provider": SensorProvider},
    'company': {
      "uri": "company",
      "model": Company,
      "provider": CompanyProvider
    },
  };

  BaseProvider provider = BaseProvider();
  provider.setModel(models[name]['model']);
  provider.setUrl(models[name]['uri']);
  return provider;
}

class BaseProvider extends GetConnect {
  var element;

  String itemUrl = "";

  final systemBox = GetStorage();

  void setModel(dynamic elem) {
    element = elem;
  }

  void setUrl(String url) {
    itemUrl = url;
  }

  @override
  void onInit() {
    httpClient.defaultDecoder = (map) {
      if (map is Map<String, dynamic> && map.containsKey('error')) {
        print('error');
      } else if (map is Map<String, dynamic> &&
          map.containsKey('data') == false) {
        return element.fromJson(map);
      } else if (map is Map<String, dynamic> && map.containsKey('data')) {
        return map['data'].map((item) => element.fromJson(item)).toList();
      }
    };
    super.onInit();
    httpClient.baseUrl = 'http://localhost/api';
  }

  Future<BaseModel?> getItem(int id) async {
    final response = await get('$itemUrl/$id/');
    return response.body;
  }

  Future<dynamic> getOptions() async {
    final response = await request("${httpClient.baseUrl}$itemUrl", "OPTIONS");
    print(response);
    return response.headers;
  }

  Future<List<dynamic?>> getItemList({required Map params}) async {
    var extras = "";

    params.forEach((key, value) {
      extras += extras != "" ? "&" : "";
      var baseKey = key;
      if (['order_by', 'limit', 'skip'].indexOf(key) > -1) baseKey = "_$key";
      extras += "$baseKey=$value";
    });

    extras = extras != "" ? "?$extras" : "";
    final headers = {"Authorization": "Bearer ${systemBox.read("jwt")}"};
    final response = await get("/$itemUrl/", headers: headers);
    // if (response.statusCode != 200) throw Exception(response.statusCode);
    return response.body;
  }

  Future<Response<BaseModel>> postItem(BaseModel item) async =>
      await post('$itemUrl/', item);

  Future<Response<BaseModel>> putItem(BaseModel item, String id) async =>
      await put('$itemUrl/$id/', item);
  Future<Response> deleteItem(int id) async => await delete('$itemUrl/$id/');
}
