import 'package:flutter/material.dart';
import 'package:hordev2/app/data/models/antodis_menu_item.dart';

class AntodisMenu extends StatefulWidget {
  final List<AntodisMenuItem> items;
  final bool minMenu;

  const AntodisMenu({Key? key, required this.items, required this.minMenu})
      : super(key: key);

  @override
  _AntodisMenu createState() => _AntodisMenu();
}

class _AntodisMenu extends State<AntodisMenu> {
  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        if (widget.minMenu == true) {
          return SizedBox(
            width: 50,
            child: Container(
              color: Color(0xFF0f1621),
              child: Column(
                children: [
                  SizedBox(
                    height: 20,
                  ),
                  CircleAvatar(),
                  ...List.generate(widget.items.length, (index) {
                    AntodisMenuItem item = widget.items[index];
                    return Column(
                      children: [
                        SizedBox(
                          height: 5,
                        ),
                        AnimatedContainer(
                            duration: Duration(milliseconds: 1000),
                            margin: EdgeInsets.only(left: 5),
                            width: 50,
                            height: 50,
                            decoration: item.onOpened == true
                                ? BoxDecoration(
                                    color: Color(0xff161e29),
                                    borderRadius: BorderRadius.only(
                                        bottomLeft: Radius.circular(10),
                                        topLeft: Radius.circular(10)))
                                : BoxDecoration(),
                            child: InkWell(
                              onTap: () {
                                widget.items.forEach((element) {
                                  element.onOpened = false;
                                });
                                item.onOpened = true;
                                setState(() {});
                              },
                              child: Icon(
                                item.icon,
                                color: item.onOpened == true
                                    ? Colors.white
                                    : Color(0xff546884),
                              ),
                            )),
                        AnimatedContainer(
                          duration: Duration(seconds: 1),
                          height: item.onOpened == true ? 100 : 0,
                          curve: Curves.bounceOut,
                          child: RotatedBox(
                            quarterTurns: 3,
                            child: Container(
                              padding: EdgeInsets.only(left: 10),
                              width: 200,
                              child: Text(
                                item.name,
                                maxLines: 1,
                              ),
                            ),
                          ),
                        ),
                      ],
                    );
                  }),
                ],
              ),
            ),
          );
        } else {
          return SizedBox(
            width: 200,
            child: Container(
              alignment: Alignment.topLeft,
              color: Color(0xFF0f1621),
              child: Column(
                children: [
                  SizedBox(
                    height: 20,
                  ),
                  CircleAvatar(),
                  ...List.generate(widget.items.length, (index) {
                    AntodisMenuItem item = widget.items[index];
                    return Column(
                      children: [
                        SizedBox(
                          height: 5,
                        ),
                        AnimatedContainer(
                            duration: Duration(milliseconds: 200),
                            margin: EdgeInsets.only(left: 5),
                            width: 200,
                            height: item.onOpened == true?80:50,
                            decoration: item.onOpened == true
                                ? BoxDecoration(
                                    color: Color(0xff161e29),
                                    borderRadius: BorderRadius.only(
                                        bottomLeft: Radius.circular(10),
                                        topLeft: Radius.circular(10)))
                                : BoxDecoration(),
                            child: InkWell(
                              onTap: () {
                                widget.items.forEach((element) {
                                  element.onOpened = false;
                                });
                                item.onOpened = true;
                                setState(() {});
                              },
                              child: Row(
                                children: [
                                  SizedBox(width: 20,),
                                  Icon(
                                    item.icon,
                                    color: item.onOpened == true
                                        ? Colors.white
                                        : Color(0xff546884),
                                  ),
                                  SizedBox(width: 20,),
                                  Text(
                                    item.name,
                                    style: TextStyle(color:item.onOpened == true
                                        ? Colors.white
                                        : Color(0xff546884)),
                                    maxLines: 1,
                                  )
                                ],
                              ),
                            )),
                      ],
                    );
                  }),
                ],
              ),
            ),
          );
        }
      },
    );
  }
}
