import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'dart:math' as math;

class RadialProgressBarPainter extends CustomPainter {
  final double value;
  late double arcSweep;
  final Color? color;
  static const double _twoPi = math.pi * 2.0;
  static const double _epsilon = .001;
  // Canvas.drawArc(r, 0, 2*PI) doesn't draw anything, so just get close.
  static const double _sweep = _twoPi - _epsilon;
  static const double _startAngle = -math.pi / 2.0;
  double? headValue;
  double? tailValue;
  RadialProgressBarPainter(this.value, this.color) {

    arcSweep = value.clamp(0.0, 1.0) * _sweep;


  }

  @override
  void paint(Canvas canvas, Size size) {
    final Paint paint = Paint()
      ..color = color!
      ..strokeWidth = 8
      ..style = PaintingStyle.stroke;

    final Paint paintBg = Paint()
      ..color = color!.withAlpha(10)
      ..strokeWidth = 8
      ..style = PaintingStyle.stroke;
    final Paint paintBgDn = Paint()
      ..color = color!.withAlpha(25)
      ..strokeWidth = 8
      ..style = PaintingStyle.fill;

    canvas.drawArc(Offset.zero & size, 4.5, 7, false, paintBg);
    canvas.drawArc(Offset.zero & size, 4.5, 7, false, paintBgDn);
    canvas.drawArc(Offset.zero & size, 4.7, arcSweep, false, paint);
  }

  @override
  bool shouldRepaint(RadialProgressBarPainter oldDelegate) {
    return oldDelegate != value;
  }

}

class RadialProgressBar extends StatefulWidget {
  final double value;
  final bool? startAnimation;
  final Color? color;
  const RadialProgressBar({Key? key, required this.value, this.startAnimation=true, this.color=Colors.white}) : super(key: key);
  @override
  _RadialProgressBar createState() => _RadialProgressBar();

}

class _RadialProgressBar extends State<RadialProgressBar> {
  late double value = 0.0;
  @override
  void initState() {

    if (widget.startAnimation == true) {
      Timer.periodic(Duration(milliseconds: 1), (Timer timer) {
        if (value >=widget.value) timer.cancel();
        setState(() {
          value += 0.005;
        });
      });
    } else {
      value = widget.value;
    }
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 50,
      height: 50,
      child: Stack(
        children: [
          Positioned(child: Center(
            child: CustomPaint(
              size: Size(50,50),

              painter: RadialProgressBarPainter(value, widget.color),
            ),
          )),
          Positioned(child: Center(child: Text("${(value*100).toInt()}"),))
        ],
      ),
    );
  }

}