import 'package:flutter/material.dart';

import 'package:get/get.dart';
import 'package:hordev2/app/data/models/antodis_menu_item.dart';
import 'package:hordev2/app/data/widgets/horde_box.dart';
import 'package:hordev2/app/data/widgets/linear_progress.dart';
import 'package:hordev2/app/data/widgets/liquid_progress.dart';
import 'package:hordev2/app/data/widgets/menu.dart';
import 'package:hordev2/app/data/widgets/progressbar.dart';
import 'package:hordev2/app/data/widgets/wave.dart';
import 'package:hordev2/app/example/bar_chart.dart';
import 'package:hordev2/app/example/data_table_example.dart';
import 'package:hordev2/app/example/line_chart.dart';
import 'package:ionicons/ionicons.dart';
import 'package:liquid_progress_indicator/liquid_progress_indicator.dart';

import '../controllers/home_controller.dart';

class HomeView extends GetView<HomeController> {
  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        return Scaffold(
          body: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Expanded(
                  child: Row(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  AntodisMenu(minMenu: constraints.maxWidth < 800, items: [
                    AntodisMenuItem(
                        icon: Ionicons.layers_outline,
                        name: 'Dashboard',
                        onTap: () {}),
                    AntodisMenuItem(
                        icon: Ionicons.cloud_upload_outline,
                        name: 'Collectors',
                        onTap: () {}),
                    AntodisMenuItem(
                        icon: Ionicons.laptop_outline,
                        name: 'Machines',
                        onTap: () {}),
                    AntodisMenuItem(
                        icon: Ionicons.wifi_outline,
                        name: 'Sensors',
                        onTap: () {}),
                  ]),
                  Expanded(
                    child: Padding(
                      padding: EdgeInsets.all(20),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "Dashboard",
                            style: Theme.of(context).textTheme.headline5,
                          ),
                          SizedBox(
                            height: 40,
                          ),
                          Expanded(
                              child: SingleChildScrollView(
                            scrollDirection: Axis.vertical,
                            child: Wrap(
                              spacing: 10,
                              runSpacing: 10,
                              children: [
                                Container(
                                  width: 100,
                                  height: 120,
                                  child: Center(),
                                ),
                                Container(
                                  width: 200,
                                  height: 120,
                                  child: LiquidCircularProgressIndicator(
                                    value: 0.25, // Defaults to 0.5.
                                    valueColor: AlwaysStoppedAnimation(Colors
                                        .pink), // Defaults to the current Theme's accentColor.
                                    backgroundColor: Colors
                                        .transparent, // Defaults to the current Theme's backgroundColor.
                                    borderColor: Colors.transparent,
                                    borderWidth: 0.0,
                                    direction: Axis
                                        .vertical, // The direction the liquid moves (Axis.vertical = bottom to top, Axis.horizontal = left to right). Defaults to Axis.vertical.
                                    center: Text("Loading..."),
                                  ),
                                ),
                                HordeBoxColor(
                                  color: Colors.red,
                                  child: Column(
                                    children: [
                                      Text('OEE'),
                                      Container(
                                        width: 100,
                                        height: 100,
                                        child: RadialProgressBar(
                                          value: 0.25,
                                          color: Colors.red,
                                        ),
                                      )
                                    ],
                                  ),
                                ),
                                HordeBoxColor(
                                  color: Colors.blue,
                                  child: Container(
                                    child: Column(
                                      children: [
                                        Text('Daily Error'),
                                        Container(
                                          width: 150,
                                          height: 100,
                                          child: ExampleBarChart(),
                                        )
                                      ],
                                    ),
                                  ),
                                ),
                                HordeBoxColor(
                                  color: Colors.yellow,
                                  child: Container(
                                    child: Column(
                                      children: [
                                        Text('Daily Error'),
                                        SizedBox(
                                          height: 25,
                                        ),
                                        Container(
                                          width: 100,
                                          height: 75,
                                          child: ExampleLineChart(),
                                        )
                                      ],
                                    ),
                                  ),
                                ),
                                HordeBoxColor(
                                    color: Colors.purple,
                                    child: Column(
                                      children: [Text('wow')],
                                    )),
                                HordeBoxColor(
                                  color: Colors.lightGreen,
                                  child: Container(
                                    child: Column(
                                      children: [
                                        Text('Daily Error'),
                                        SizedBox(
                                          height: 25,
                                        ),
                                        Container(
                                          width: 200,
                                          height: 50,
                                          child: ExampleLineChart(),
                                        ),
                                        MaterialButton(
                                          onPressed: () {},
                                          child: Text('Sample Button'),
                                        )
                                      ],
                                    ),
                                  ),
                                ),
                                HordeBox(
                                  title: "Test",
                                  actionList: [],
                                  child: Container(
                                    child: Column(
                                      children: [
                                        SizedBox(
                                          height: 25,
                                        ),
                                        Container(
                                          width: 200,
                                          height: 50,
                                          child: ExampleLineChart(),
                                        ),
                                        MaterialButton(
                                            onPressed: () {},
                                            child: Text('Sample Button'))
                                      ],
                                    ),
                                  ),
                                ),
                                HordeBoxColor(
                                    color: Colors.red,
                                    child: SizedBox(
                                      child: DataTableExample(),
                                    ))
                              ],
                            ),
                          ))
                        ],
                      ),
                    ),
                  )
                ],
              ))
            ],
          ),
        );
      },
    );
  }
}
